@@ -13,4 +13,6 @@
 #You should have received a copy of the GNU General Public License
 #along with reparted.  If not, see <http://www.gnu.org/licenses/>.
 
-__all__ = ['conversion', 'size', 'device', 'disk']
+from .size import Size
+from .device import Device
+from .disk import Disk, Partition
